@@ -23,6 +23,7 @@ from tencentcloud.ssl.v20191205 import models
 class SslClient(AbstractClient):
     _apiVersion = '2019-12-05'
     _endpoint = 'ssl.tencentcloudapi.com'
+    _service = 'ssl'
 
 
     def ApplyCertificate(self, request):
@@ -138,7 +139,7 @@ class SslClient(AbstractClient):
 
 
     def CompleteCertificate(self, request):
-        """本接口（CompleteCertificate）用于主动触发证书验证。
+        """本接口（CompleteCertificate）用于主动触发证书验证。仅非DNSPod和Wotrus品牌证书支持使用此接口。
 
         :param request: Request instance for CompleteCertificate.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CompleteCertificateRequest`
@@ -221,6 +222,34 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteManager(self, request):
+        """删除管理人
+
+        :param request: Request instance for DeleteManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DeleteManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DeleteManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCertificate(self, request):
         """本接口（DescribeCertificate）用于获取证书信息。
 
@@ -333,6 +362,62 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeManagerDetail(self, request):
+        """查询管理人详情
+
+        :param request: Request instance for DescribeManagerDetail.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeManagerDetailRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeManagerDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeManagerDetail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeManagerDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeManagers(self, request):
+        """查询管理人列表
+
+        :param request: Request instance for DescribeManagers.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeManagersRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeManagersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeManagers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeManagersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DownloadCertificate(self, request):
         """本接口（DownloadCertificate）用于下载证书。
 
@@ -473,8 +558,36 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SubmitAuditManager(self, request):
+        """重新提交审核管理人
+
+        :param request: Request instance for SubmitAuditManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.SubmitAuditManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.SubmitAuditManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SubmitAuditManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SubmitAuditManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SubmitCertificateInformation(self, request):
-        """提交证书资料。
+        """提交证书资料。输入参数信息可以分多次提交，但提交的证书资料应最低限度保持完整。
 
         :param request: Request instance for SubmitCertificateInformation.
         :type request: :class:`tencentcloud.ssl.v20191205.models.SubmitCertificateInformationRequest`
@@ -578,6 +691,34 @@ class SslClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def VerifyManager(self, request):
+        """重新核验管理人
+
+        :param request: Request instance for VerifyManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.VerifyManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.VerifyManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("VerifyManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.VerifyManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
